- **Colin Duquesnoy** (@ColinDuquesnoy)
    Main developper

- **Céline Thiry** (@CelineThiry)
    Graphic designer (application icon)

- **Simon Sobisch** (@GitMensch)
    Testing

- **Gatien Bovyn** (@Astalaseven)
    Testing/Code Contributor

- **Vlinhart** (@vlinhart)
    Contributor (documentation)
